@@ -252,12 +252,12 @@ class Jenkins():
     def get_url(self, group_name, repository_name):
         return f"{self.base_url}/project/{group_name}/{repository_name}"
 
-    def create_job(self, group_name, repository_name, description):
+    def create_job(self, group_name, repository_name, description, gitlab_url):
         repository_full_name = f"{group_name}/{repository_name}"
-        config = self.get_default_job_config(group_name, repository_name, description)
+        config = self.get_default_job_config(gitlab_url, group_name, repository_name, description)
         self.jnks.create_job(repository_full_name, config)
 
-    def get_default_job_config(self, group_name, repository_name, description):
+    def get_default_job_config(self, gitlab_url, group_name, repository_name, description):
         DEFAULT_CONFIG = """<?xml version='1.1' encoding='UTF-8'?>
 <flow-definition plugin="workflow-job@2.42">
   <actions>
@@ -276,7 +276,7 @@ class Jenkins():
       <abortPrevious>false</abortPrevious>
     </org.jenkinsci.plugins.workflow.job.properties.DisableConcurrentBuildsJobProperty>
     <com.coravy.hudson.plugins.github.GithubProjectProperty plugin="github@1.33.1">
-      <projectUrl>https://gitlab.stonebranch.com/{repository}/</projectUrl>
+      <projectUrl>{gitlab_url}/{repository}/</projectUrl>
       <displayName></displayName>
     </com.coravy.hudson.plugins.github.GithubProjectProperty>
     <com.dabsquared.gitlabjenkins.connection.GitLabConnectionProperty plugin="gitlab-plugin@1.5.22">
@@ -323,7 +323,7 @@ class Jenkins():
       <configVersion>2</configVersion>
       <userRemoteConfigs>
         <hudson.plugins.git.UserRemoteConfig>
-          <url>https://gitlab.stonebranch.com/{repository}.git</url>
+          <url>{gitlab_url}/{repository}.git</url>
           <credentialsId>cs_jenkins_gitlab_personal_access_token</credentialsId>
         </hudson.plugins.git.UserRemoteConfig>
       </userRemoteConfigs>
@@ -334,7 +334,7 @@ class Jenkins():
       </branches>
       <doGenerateSubmoduleConfigurations>false</doGenerateSubmoduleConfigurations>
       <browser class="hudson.plugins.git.browser.GitLab">
-        <url>https://gitlab.stonebranch.com/{repository}</url>
+        <url>{gitlab_url}/{repository}</url>
         <version>14.0</version>
       </browser>
       <submoduleCfg class="empty-list"/>
@@ -347,4 +347,8 @@ class Jenkins():
   <disabled>false</disabled>
 </flow-definition>"""
         repository = f"{group_name}/{repository_name}"
-        return DEFAULT_CONFIG.format(repository=repository, description=description, token="{AQAAABAAAAAwn0PMV7WTFCnRSkwbTfvm7603mkro7e+5PvP0NTkPaQIr4W1q6U2c6FvDwBq3Uq+PV3zDPI4vRD+YohxEdVgxRg==}")
\ No newline at end of file
+        return DEFAULT_CONFIG.format(
+            repository=repository,
+            description=description,
+            token="{AQAAABAAAAAwn0PMV7WTFCnRSkwbTfvm7603mkro7e+5PvP0NTkPaQIr4W1q6U2c6FvDwBq3Uq+PV3zDPI4vRD+YohxEdVgxRg==}",
+            gitlab_url=gitlab_url)
\ No newline at end of file
